==> openads-2.3.34-beta.tar.gz: openads-2.3.34-beta/lib/max/language/german/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| Openads v2.3                                                              |
| ============                                                              |
|                                                                           |
| Copyright (c) 2003-2007 Openads Limited                                   |
| For contact details, see: http://www.openads.org/                         |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 6032 2007-04-25 16:12:07Z aj@seagullproject.org $
*/

// German
// Invocation Types
$GLOBALS['strInvocationRemote']		= "Standardbannercode (Remote)";
$GLOBALS['strInvocationJS']			= "Bannercode f&uuml;r JavaScript";
$GLOBALS['strInvocationIframes']		= "Bannercode f&uuml;r Frames (iframe/ilayer)";
$GLOBALS['strInvocationXmlRpc']		= "Bannercode f&uuml;r Nutzung von XML-RPC";
$GLOBALS['strInvocationCombined']		= "Kombinierter Bannercode";
$GLOBALS['strInvocationPopUp']			= "Pop-Up";
$GLOBALS['strInvocationAdLayer']		= "Interstitial-oder Floating-DHTML";
$GLOBALS['strInvocationLocal']			= "Lokaler Modus";
//neu in MMM 0.3
$GLOBALS['strInvocationRemoteNoCookies']	= "Standardbannercode (Remote) - Keine Cookies";


// Other
$GLOBALS['strCopyToClipboard']			= "Kopieren in Zwischenablage";
$GLOBALS['strCopy']				            = "kopieren";


// Measures
$GLOBALS['strAbbrPixels']			= "Px";
$GLOBALS['strAbbrSeconds']			= "Sek";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Werbemittelauswahl";
$GLOBALS['strInvocationClientID']		= "Werbetreibender oder Kampagne";
$GLOBALS['strInvocationTarget']			= "Zielfenster (target frame)";
$GLOBALS['strInvocationSource']			= "Quelle";
$GLOBALS['strInvocationWithText']		= "Textanzeige unterhalb Werbemittel";
$GLOBALS['strInvocationDontShowAgain']		= "Werbemittel auf derselben Seite nicht mehrfach anzeigen";
$GLOBALS['strInvocationDontShowAgainCampaign']		= "Werbemittel derselben Kampagne nicht mehrfach auf derselben Seite anzeigen";
$GLOBALS['strInvocationTemplate'] 		= "Um Templates nutzen zu k&ouml;nnen, Werbemittel in einer Variablen speichern";
//neu in MMM 0.3
$GLOBALS['strInvocationPreview']					= "Vorschau Werbemittel";
$GLOBALS['strInvocationCampaignID']					= "Kampagne";
$GLOBALS['strInvocationBannerID']					= "Werbemittel-ID";

// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Erneuern (refresh) nach ";
$GLOBALS['strIframeResizeToBanner']		= "Iframe an die Bannergr&ouml;&szlig;e anpassen";
$GLOBALS['strIframeMakeTransparent']		= "Iframe transparent darstellen";
$GLOBALS['strIframeIncludeNetscape4']		= "Netscape 4 kompatiblen ilayer (zus&auml;tzlich)";


// PopUp
$GLOBALS['strPopUpStyle']			= "Pop-Up-Typ";
$GLOBALS['strPopUpStylePopUp']		= "Pop-Up";
$GLOBALS['strPopUpStylePopUnder']		= "Pop-Under";
$GLOBALS['strPopUpCreateInstance']		= "Zeitpunkt zu dem das Pop-Up erscheinen wird";
$GLOBALS['strPopUpImmediately']		= "Sofort";
$GLOBALS['strPopUpOnClose']			= "Wenn die Seite geschlossen wird";
$GLOBALS['strPopUpAfterSec']			= "Nach";
$GLOBALS['strAutoCloseAfter']			= "Schlie&szlig;t automatisch nach";
$GLOBALS['strPopUpTop']			= "Startposition (oben)";
$GLOBALS['strPopUpLeft']			= "Startposition (links)";
$GLOBALS['strWindowOptions']			= "Window-Optionen";
$GLOBALS['strShowToolbars']			= "Werkzeugleiste";
$GLOBALS['strShowLocation']			= "Standortleiste";
$GLOBALS['strShowMenubar']			= "Men&uuml;leiste";
$GLOBALS['strShowStatus']			= "Statusleiste";
$GLOBALS['strWindowResizable']		= "G&ouml;&szlig;e anpassen";
$GLOBALS['strShowScrollbars']			= "Scroll-Leiste";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Sprache auf Host";
$GLOBALS['strXmlRpcProtocol']       = "HTTPS nutzen, um den XML-RPC Server zu kontaktieren";
$GLOBALS['strXmlRpcTimeout']        = "XML-RPC Timeout (in Sekunden)";

// AdLayer
$GLOBALS['strAdLayerStyle']			= "Stil";

$GLOBALS['strAlignment']			= "Ausrichtung";
$GLOBALS['strHAlignment']			= "Horizontale Ausrichtung";
$GLOBALS['strLeft']					= "Links";
$GLOBALS['strCenter']				= "Zentriert";
$GLOBALS['strRight']				= "Rechts";

$GLOBALS['strVAlignment']			= "Vertikale Ausrichtung";
$GLOBALS['strTop']					= "Oben";
$GLOBALS['strMiddle']				= "Mitte";
$GLOBALS['strBottom']				= "Unten";

$GLOBALS['strAutoCollapseAfter']		= "Automatisch einklappen nach";
$GLOBALS['strCloseText']			= "Schlie&szlig;text";
$GLOBALS['strClose']				= "[Schlie&szlig;en]";
$GLOBALS['strBannerPadding']			= "Banner ausf&uuml;llen";

$GLOBALS['strHShift']				= "Horizontal verschieben";
$GLOBALS['strVShift']				= "Vertikal verschieben";

$GLOBALS['strShowCloseButton']		= "Anzeigen Ende-Button";
$GLOBALS['strBackgroundColor']		= "Hintergrundfarbe";
$GLOBALS['strBorderColor']			= "Farbe des Randes";

$GLOBALS['strDirection']			= "Richtung";
$GLOBALS['strLeftToRight']			= "Links nach rechts";
$GLOBALS['strRightToLeft']			= "Rechts nach links";
$GLOBALS['strLooping']				= "Schleifen";
$GLOBALS['strAlwaysActive']			= "Immer aktiv";
$GLOBALS['strSpeed']				= "Geschwindigkeit";
$GLOBALS['strPause']				= "Pause";
$GLOBALS['strLimited']				= "Limitiert";
$GLOBALS['strLeftMargin']			= "Linker Rand";
$GLOBALS['strRightMargin']			= "Rechter Rand";
$GLOBALS['strTransparentBackground']		= "Transparenter Hintergrund";

$GLOBALS['strSmoothMovement']		= "Ruhige Bewegung";
$GLOBALS['strHideNotMoving']			= "Verberge Banner, wenn Cursor nicht bewegt wird";
$GLOBALS['strHideDelay']			= "Verz&ouml;gerung bis zum Verbergen des Banners";
$GLOBALS['strHideTransparancy']		= "Transparenz des verborgenen Banners";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "Geocities",
	'simple'		=> "Einfach",
	'cursor'		=> "Cursor",
	'floater'		=> "Floater"
);

// Support for 3rd party server clicktracking
$GLOBALS['str3rdPartyTrack']		= "3rd Party Server Klick-Tracking unterst&uuml;tzen";

// Support for cachebusting code
$GLOBALS['strCacheBuster']		    = "Cache-Busting Code einf&uuml;gen";

// Non-Img creatives Warning for zone image-only invocation
$GLOBALS['strNonImgWarningZone']	= "Warnung: Dieser Ad-Tag enth&auml;lt Werbemittel, die keine Banner sind. Diese Werbemittel werden durch diese Zone nicht ausgeliefert.";
$GLOBALS['strNonImgWarning']        = "Warnung: Dieser Ad-Tag wird nicht ausgeliefert werden, weil das Werbemittel kein Banner ist.";

// unkown HTML tag type Warning for zone invocation
$GLOBALS['strUnknHtmlWarning']      = "Warnung: Dieses Werbemittel verwendet ein unbekanntes HTML-Ad Format.";

// sql/web banner-type warning for clickonly zone invocation
$GLOBALS['strWebBannerWarning']     = "Warnung: Dieses Werbemittel mu&szlig; heruntergeladen werden und Sie m&uuml;ssen uns die korrekte Klick-URL f&uuml;r dieses Werbemittel senden.
<br /> 1) Banner-Download:";
$GLOBALS['strDwnldWebBanner']       = "Mit der rechten Maustaste klicken und Ziel speichern als ausw&auml;hlen";
$GLOBALS['strWebBannerWarning2']    = "<br /> 2) Laden Sie das Banner auf Ihren Web-Server und geben Sie die URL hier an: ";

// IMG invocation selected for tracker with appended code
$GLOBALS['strWarning'] = "Warnung";
$GLOBALS['strImgWithAppendWarning'] = "Dieser Tracker hat angeh&auml;ngten Code.<br />Angeh&auml;ngter Code kann nur &uuml;ber JavaScript-Tags ausgef&uuml;hrt werden";

?>

==> openads-2.3.39-beta.tar.gz: openads-2.3.39-beta/lib/max/language/german/invocation.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| Openads v2.3                                                              |
| ============                                                              |
|                                                                           |
| Copyright (c) 2003-2007 Openads Limited                                   |
| For contact details, see: http://www.openads.org/                         |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: invocation.lang.php 8176 2007-07-13 12:34:49Z andrew.hill@openads.org $
*/

// Other
$GLOBALS['strCopyToClipboard']			= "Kopieren in Zwischenablage";
$GLOBALS['strCopy']				            = "kopieren";


// Measures
$GLOBALS['strAbbrPixels']			= "Px";
$GLOBALS['strAbbrSeconds']			= "Sek";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Werbemittelauswahl";
$GLOBALS['strInvocationPreview']					= "Vorschau Werbemittel";
$GLOBALS['strInvocationClientID']		= "Werbetreibender oder Kampagne";
$GLOBALS['strInvocationCampaignID']					= "Kampagne";
$GLOBALS['strInvocationTarget']			= "Zielfenster (target frame)";
$GLOBALS['strInvocationSource']			= "Quelle";
$GLOBALS['strInvocationWithText']		= "Textanzeige unterhalb Werbemittel";
$GLOBALS['strInvocationDontShowAgain']		= "Werbemittel auf derselben Seite nicht mehrfach anzeigen";
$GLOBALS['strInvocationDontShowAgainCampaign']		= "Werbemittel derselben Kampagne nicht mehrfach auf derselben Seite anzeigen";
$GLOBALS['strInvocationTemplate'] 		= "Um Templates nutzen zu k&ouml;nnen, Werbemittel in einer Variablen speichern";
$GLOBALS['strInvocationBannerID']					= "Werbemittel-ID";
$GLOBALS['strInvocationComments']                   = "Kommentare hinzuf&uuml;gen";

// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Erneuern (refresh) nach ";
$GLOBALS['strIframeResizeToBanner']		= "Iframe an die Bannergr&ouml;&szlig;e anpassen";
$GLOBALS['strIframeMakeTransparent']		= "Iframe transparent darstellen";
$GLOBALS['strIframeIncludeNetscape4']		= "Netscape 4 kompatiblen ilayer (zus&auml;tzlich)";


// PopUp
$GLOBALS['strPopUpStyle']			= "PopUp Typ";
$GLOBALS['strPopUpStylePopUp']		= "PopUp";
$GLOBALS['strPopUpStylePopUnder']		= "PopUnder";
$GLOBALS['strPopUpCreateInstance']		= "Zeitpunkt zu dem das PopUp erscheinen wird";
$GLOBALS['strPopUpImmediately']		= "Sofort";
$GLOBALS['strPopUpOnClose']			= "Wenn die Seite geschlossen wird";
$GLOBALS['strPopUpAfterSec']			= "Nach";
$GLOBALS['strAutoCloseAfter']			= "Schlie&szlig;t automatisch nach";
$GLOBALS['strPopUpTop']			= "Startposition (oben)";
$GLOBALS['strPopUpLeft']			= "Startposition (links)";
$GLOBALS['strWindowOptions']			= "Window-Optionen";
$GLOBALS['strShowToolbars']			= "Werkzeugleiste";
$GLOBALS['strShowLocation']			= "Standortleiste";
$GLOBALS['strShowMenubar']			= "Men&uuml;leiste";
$GLOBALS['strShowStatus']			= "Statusleiste";
$GLOBALS['strWindowResizable']		= "G&ouml;&szlig;e anpassen";
$GLOBALS['strShowScrollbars']			= "Scroll-Leiste";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Sprache auf Host";
$GLOBALS['strXmlRpcProtocol']       = "HTTPS nutzen, um den XML-RPC Server zu kontaktieren";
$GLOBALS['strXmlRpcTimeout']        = "XML-RPC Timeout (in Sekunden)";

// AdLayer
$GLOBALS['strAdLayerStyle']			= "Stil";

$GLOBALS['strAlignment']			= "Ausrichtung";
$GLOBALS['strHAlignment']			= "Horizontale Ausrichtung";
$GLOBALS['strLeft']					= "Links";
$GLOBALS['strCenter']				= "Zentriert";
$GLOBALS['strRight']				= "Rechts";

$GLOBALS['strVAlignment']			= "Vertikale Ausrichtung";
$GLOBALS['strTop']					= "Oben";
$GLOBALS['strMiddle']				= "Mitte";
$GLOBALS['strBottom']				= "Unten";

$GLOBALS['strAutoCollapseAfter']		= "Automatisch einklappen nach";
$GLOBALS['strCloseText']			= "Schlie&szlig;text";
$GLOBALS['strClose']				= "[Schlie&szlig;en]";
$GLOBALS['strBannerPadding']			= "Banner ausf&uuml;llen";

$GLOBALS['strHShift']				= "Horizontal verschieben";
$GLOBALS['strVShift']				= "Vertikal verschieben";

$GLOBALS['strShowCloseButton']		= "Anzeigen Ende-Button";
$GLOBALS['strBackgroundColor']		= "Hintergrundfarbe";
$GLOBALS['strBorderColor']			= "Farbe des Randes";

$GLOBALS['strDirection']			= "Richtung";
$GLOBALS['strLeftToRight']			= "Links nach rechts";
$GLOBALS['strRightToLeft']			= "Rechts nach links";
$GLOBALS['strLooping']				= "Schleifen";
$GLOBALS['strAlwaysActive']			= "Immer aktiv";
$GLOBALS['strSpeed']				= "Geschwindigkeit";
$GLOBALS['strPause']				= "Pause";
$GLOBALS['strLimited']				= "Limitiert";
$GLOBALS['strLeftMargin']			= "Linker Rand";
$GLOBALS['strRightMargin']			= "Rechter Rand";
$GLOBALS['strTransparentBackground']		= "Transparenter Hintergrund";

$GLOBALS['strSmoothMovement']		= "Ruhige Bewegung";
$GLOBALS['strHideNotMoving']			= "Verberge Banner, wenn Cursor nicht bewegt wird";
$GLOBALS['strHideDelay']			= "Verz&ouml;gerung bis zum Verbergen des Banners";
$GLOBALS['strHideTransparancy']		= "Transparenz des verborgenen Banners";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "Geocities",
	'simple'		=> "Einfach",
	'cursor'		=> "Cursor",
	'floater'		=> "Floater"
);

// Support for 3rd party server clicktracking
$GLOBALS['str3rdPartyTrack']		= "3rd Party Server Klick-Tracking unterst&uuml;tzen";

// Support for cachebusting code
$GLOBALS['strCacheBuster']		    = "Cache-Busting Code einf&uuml;gen";

// Non-Img creatives Warning for zone image-only invocation
$GLOBALS['strNonImgWarningZone']	= "Warnung: Dieser Ad-Tag enth&auml;lt Werbemittel, die keine Banner sind. Diese Werbemittel werden durch diese Zone nicht ausgeliefert.";
$GLOBALS['strNonImgWarning']        = "Warnung: Dieser Ad-Tag wird nicht ausgeliefert werden, weil das Werbemittel kein Banner ist.";

// unkown HTML tag type Warning for zone invocation
$GLOBALS['strUnknHtmlWarning']      = "Warnung: Dieses Werbemittel verwendet ein unbekanntes HTML-Ad Format.";

// sql/web banner-type warning for clickonly zone invocation
$GLOBALS['strWebBannerWarning']     = "Warnung: Dieses Werbemittel mu&szlig; heruntergeladen werden und Sie m&uuml;ssen uns die korrekte Klick-URL f&uuml;r dieses Werbemittel senden.
<br /> 1) Banner-Download:";
$GLOBALS['strDwnldWebBanner']       = "Mit der rechten Maustaste klicken und Ziel speichern als ausw&auml;hlen";
$GLOBALS['strWebBannerWarning2']    = "<br /> 2) Laden Sie das Banner auf Ihren Web-Server und geben Sie die URL hier an: ";

// IMG invocation selected for tracker with appended code
$GLOBALS['strWarning'] = "Warnung";
$GLOBALS['strImgWithAppendWarning'] = "Dieser Tracker hat angeh&auml;ngten Code.<br />Angeh&auml;ngter Code kann nur &uuml;ber JavaScript-Tags ausgef&uuml;hrt werden";

?>
